netapp_ontap.models.consistency_group_response_records_consistency_groups_luns API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.consistency_group_response_records_consistency_groups_luns`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ConsistencyGroupResponseRecordsConsistencyGroupsLunsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ConsistencyGroupResponseRecordsConsistencyGroupsLuns object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `clone: ConsistencyGroupConsistencyGroupsLunsClone POST PATCH`

    This sub-object is used in POST to create a new LUN as a clone of an existing LUN, or PATCH to overwrite an existing LUN as a clone of another. Setting a property in this sub-object indicates that a LUN clone is desired. Consider the following other properties when cloning a LUN: `auto_delete`, `qos_policy`, `space.guarantee.requested` and `space.scsi_thin_provisioning_support_enabled`.
    When used in a PATCH, the patched LUN's data is over-written as a clone of the source and the following properties are preserved from the patched LUN unless otherwise specified as part of the PATCH: `class`, `auto_delete`, `lun_maps`, `serial_number`, `status.state`, and `uuid`.
    Persistent reservations for the patched LUN are also preserved. This endpoint does not support clones. No properties in this sub-object can be set for POST or PATCH and none will be returned by GET.
    Cloning is supported through the /api/storage/storage-units endpoint. See the `POST /api/storage/storage-units` to learn more about cloning LUNs.

  `comment: str GET POST PATCH`

    A configurable comment available for use by the administrator. Valid in POST and PATCH.

  `create_time: ImpreciseDateTime GET`

    The time the LUN was created.

    Example: 2018-06-04T19:00:00.000+0000

  `enabled: bool GET`

    The enabled state of the LUN. LUNs can be disabled to prevent access to the LUN. Certain error conditions also cause the LUN to become disabled. If the LUN is disabled, you can consult the `state` property to determine if the LUN is administratively disabled (offline) or has become disabled as a result of an error. A LUN in an error condition can be brought online by setting the `enabled` property to true or brought administratively offline by setting the `enabled` property to false. Upon creation, a LUN is enabled by default. Valid in PATCH.

  `lun_maps: List[ConsistencyGroupLunLunMaps] GET POST PATCH`

    An array of LUN maps.
    A LUN map is an association between a LUN and an initiator group. When a LUN is mapped to an initiator group, the initiator group's initiators are granted access to the LUN. The relationship between a LUN and an initiator group is many LUNs to many initiator groups.

  `name: str GET POST`

    The fully qualified path name of the LUN composed of the "/vol" prefix, the volume name, the qtree name (optional), and the base name of the LUN. Valid in POST and PATCH.

    Example: /vol/volume1/lun1

  `os_type: str GET POST`

    The operating system type of the LUN.
    Required in POST when creating a LUN that is not a clone of another. Disallowed in POST when creating a LUN clone.

    Valid choices:

    - aix
    - hpux
    - hyper_v
    - linux
    - netware
    - openvms
    - solaris
    - solaris_efi
    - vmware
    - windows
    - windows_2008
    - windows_gpt
    - xen
  `provisioning_options: ConsistencyGroupVdiskProvisioningOptions POST PATCH`

    Options that are applied to the operation.

  `qos: ConsistencyGroupQos GET POST PATCH`

    The qos field of the consistency_group_response_records_consistency_groups_luns.

  `serial_number: str GET`

    The LUN serial number. The serial number is generated by ONTAP when the LUN is created.

  `space: ConsistencyGroupLunSpace GET POST PATCH`

    The storage space related properties of the LUN.

  `uuid: str GET`

    The unique identifier of the LUN. The UUID is generated by ONTAP when the LUN is created.

    Example: 1cd8a442-86d1-11e0-ae1c-123478563412